
## CATO-CLI - mutation.sites.removeCloudInterconnectPhysicalConnection:
[Click here](https://api.catonetworks.com/documentation/#mutation-mutation.sites.removeCloudInterconnectPhysicalConnection) for documentation on this operation.

### Usage for mutation.sites.removeCloudInterconnectPhysicalConnection:

```bash
catocli mutation sites removeCloudInterconnectPhysicalConnection -h

catocli mutation sites removeCloudInterconnectPhysicalConnection <json>

catocli mutation sites removeCloudInterconnectPhysicalConnection --json-file mutation.sites.removeCloudInterconnectPhysicalConnection.json

catocli mutation sites removeCloudInterconnectPhysicalConnection '{"removeCloudInterconnectPhysicalConnectionInput":{"id":"id"}}'

catocli mutation sites removeCloudInterconnectPhysicalConnection '{
    "removeCloudInterconnectPhysicalConnectionInput": {
        "id": "id"
    }
}'
```

#### Operation Arguments for mutation.sites.removeCloudInterconnectPhysicalConnection ####

`accountId` [ID] - (required) N/A    
`removeCloudInterconnectPhysicalConnectionInput` [RemoveCloudInterconnectPhysicalConnectionInput] - (required) N/A    
